@@ -4,7 +4,7 @@
 python get_morphologies.py
 
 # learn diameter model
-diameter-synthesis run_models model_config.json
+diameter-synthesis run_models model_config.json --plot
 
 # rediametrize morphologies
 diameter-synthesis run_diameters diametrizer_config.json diameter_model.json
