@@ -17,12 +17,14 @@
 
 import neurom as nm
 import pytest
-from diff_pdf_visually import pdfdiff
+from diff_pdf_visually import pdf_similar
 from matplotlib import pyplot as plt
 
 from diameter_synthesis import plotting
 from diameter_synthesis.exception import DiameterSynthesisError
 
+NEURITE_TYPES = ["basal_dendrite", "apical_dendrite"]
+
 
 def test_plot_diameter_diff(neuron_diametrized_path, tmpdir, expected_images_path):
     """Test the plot_diameter_diff function."""
@@ -37,11 +39,11 @@ def test_plot_diameter_diff(neuron_diametrized_path, tmpdir, expected_images_pat
 
     # Plot the figure
     plotting.plot_diameter_diff(
-        neuron_diametrized_path, new_neuron, ["basal", "apical"], tmpdir, ext=".pdf"
+        neuron_diametrized_path, new_neuron, NEURITE_TYPES, tmpdir, ext=".pdf"
     )
 
     # Check the figure
-    assert pdfdiff(
+    assert pdf_similar(
         str(expected_images_path / "test_plot_diameter_diff_mult.pdf"),
         str(tmpdir / neuron_diametrized_path.with_suffix(".pdf").name),
     )
@@ -57,11 +59,11 @@ def test_plot_diameter_diff(neuron_diametrized_path, tmpdir, expected_images_pat
 
     # Plot the figure
     plotting.plot_diameter_diff(
-        neuron_diametrized_path, new_neuron, ["basal", "apical"], tmpdir / "new_dir", ext=".pdf"
+        neuron_diametrized_path, new_neuron, NEURITE_TYPES, tmpdir / "new_dir", ext=".pdf"
     )
 
     # Check the figure
-    assert pdfdiff(
+    assert pdf_similar(
         str(expected_images_path / "test_plot_diameter_diff_div.pdf"),
         str(tmpdir / "new_dir" / neuron_diametrized_path.with_suffix(".pdf").name),
     )
@@ -72,21 +74,17 @@ def test_plot_distribution_fit(model_params, model_data, tmpdir, expected_images
     # Plot the figure
     plotting.plot_distribution_fit(
         model_data["diameter_power_relation"],
-        model_params["generic"]["L5_TPC:A"]["diameter_power_relation"],
-        ["basal", "apical"],
+        model_params["diameter_power_relation"],
+        NEURITE_TYPES,
         fig_name=tmpdir / "test_plot_distribution_fit",
         ext=".pdf",
     )
 
     # Check the figures
-    assert pdfdiff(
+    assert pdf_similar(
         str(expected_images_path / "test_plot_distribution_fit.pdf"),
         str(tmpdir / "test_plot_distribution_fit.pdf"),
     )
-    assert pdfdiff(
-        str(expected_images_path / "test_plot_distribution_fit_scatter.pdf"),
-        str(tmpdir / "test_plot_distribution_fit_scatter.pdf"),
-    )
 
 
 def test_plot_cumulative_distribution(
@@ -99,13 +97,13 @@ def test_plot_cumulative_distribution(
         single_pop_diametrized,
         "segment_radial_distances",
         "segment_volumes",
-        ["basal", "apical"],
+        NEURITE_TYPES,
     )
     plt.savefig(tmpdir / "test_plot_cumulative_distribution.pdf", bbox_inches="tight")
     plt.close()
 
     # Check the figures
-    assert pdfdiff(
+    assert pdf_similar(
         str(expected_images_path / "test_plot_cumulative_distribution.pdf"),
         str(tmpdir / "test_plot_cumulative_distribution.pdf"),
     )
@@ -119,7 +117,7 @@ def test_make_cumulative_figures(single_pop, single_pop_diametrized, tmpdir, exp
         single_pop_diametrized,
         "segment_radial_distances",
         "segment_volumes",
-        ["basal", "apical"],
+        NEURITE_TYPES,
         tmpdir,
         individual=True,
         figname_prefix="with_individual_",
@@ -128,11 +126,11 @@ def test_make_cumulative_figures(single_pop, single_pop_diametrized, tmpdir, exp
 
     # Check the figures
     images_path = expected_images_path / "test_make_cumulative_figures"
-    assert pdfdiff(
+    assert pdf_similar(
         str(images_path / "cumulative_segment_radial_distances_volumes.pdf"),
         str(tmpdir / "with_individual_cumulative_segment_radial_distances_volumes.pdf"),
     )
-    assert pdfdiff(
+    assert pdf_similar(
         str(
             images_path
             / "cumulative_segment_radial_distances_volumes_individual"
@@ -164,21 +162,21 @@ def test_cumulative_analysis(
         tmpdir / "analysis",
         True,
         single_pop_data_dir / "neurondb.dat",
-        ["basal", "apical"],
+        NEURITE_TYPES,
         ext=".pdf",
     )
 
     # Check the figures
     images_path = expected_images_path / "test_cumulative_analysis" / "analysis"
-    assert pdfdiff(
+    assert pdf_similar(
         str(images_path / "L5_TPC_A_cumulative_section_path_distances_areas.pdf"),
         str(tmpdir / "analysis" / "L5_TPC_A_cumulative_section_path_distances_areas.pdf"),
     )
-    assert pdfdiff(
+    assert pdf_similar(
         str(images_path / "L5_TPC_A_cumulative_section_path_distances_volumes.pdf"),
         str(tmpdir / "analysis" / "L5_TPC_A_cumulative_section_path_distances_volumes.pdf"),
     )
-    assert pdfdiff(
+    assert pdf_similar(
         str(
             images_path
             / "L5_TPC_A_cumulative_section_path_distances_areas_individual"
@@ -191,7 +189,7 @@ def test_cumulative_analysis(
             / "0_L5_TPC_A_cumulative_section_path_distances_areas_C030796A-P3_lite.h5.pdf"
         ),
     )
-    assert pdfdiff(
+    assert pdf_similar(
         str(
             images_path
             / "L5_TPC_A_cumulative_section_path_distances_volumes_individual"
@@ -217,7 +215,7 @@ def test_cumulative_analysis(
             tmpdir / "analysis",
             True,
             single_pop_data_dir / "neurondb.dat",
-            ["basal", "apical"],
+            NEURITE_TYPES,
             ext=".pdf",
         )
 
@@ -235,7 +233,7 @@ def test_violin_analysis(
     )
 
     # Check the figures
-    assert pdfdiff(
+    assert pdf_similar(
         str(expected_images_path / "test_violin_analysis.pdf"),
         str(tmpdir / "analysis" / "morphometrics.pdf"),
     )
